@@ -1,4 +1,4 @@
-from datetime import datetime
+from typing import Union
 
 from pydantic import BaseModel
 from pydantic.fields import Field
@@ -15,10 +15,10 @@ class Payout(BaseModel):
     transaction_id: int
     payout_type: str
     status: str
-    amount: int | float
-    commission: int | float
+    amount: Union[int, float]
+    commission: Union[int, float]
     commission_type: str
-    exchange_rate: int | float | None = Field(None, alias='rate')
+    exchange_rate: Union[int, float, None] = Field(None, alias='rate')
     wallet: int
     date: str
     complete_date: str
